#line 2 "ascend_scanner.c"
/* Include this before everything else, for various large-file definitions */
#include "config.h"

#line 6 "ascend_scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define ascend_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer ascend_create_buffer
#endif

#ifdef yy_delete_buffer
#define ascend_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer ascend_delete_buffer
#endif

#ifdef yy_scan_buffer
#define ascend_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer ascend_scan_buffer
#endif

#ifdef yy_scan_string
#define ascend_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string ascend_scan_string
#endif

#ifdef yy_scan_bytes
#define ascend_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes ascend_scan_bytes
#endif

#ifdef yy_init_buffer
#define ascend_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer ascend_init_buffer
#endif

#ifdef yy_flush_buffer
#define ascend_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer ascend_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define ascend_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state ascend_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define ascend_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer ascend_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define ascendpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state ascendpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define ascendpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state ascendpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define ascendensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack ascendensure_buffer_stack
#endif

#ifdef yylex
#define ascendlex_ALREADY_DEFINED
#else
#define yylex ascendlex
#endif

#ifdef yyrestart
#define ascendrestart_ALREADY_DEFINED
#else
#define yyrestart ascendrestart
#endif

#ifdef yylex_init
#define ascendlex_init_ALREADY_DEFINED
#else
#define yylex_init ascendlex_init
#endif

#ifdef yylex_init_extra
#define ascendlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra ascendlex_init_extra
#endif

#ifdef yylex_destroy
#define ascendlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy ascendlex_destroy
#endif

#ifdef yyget_debug
#define ascendget_debug_ALREADY_DEFINED
#else
#define yyget_debug ascendget_debug
#endif

#ifdef yyset_debug
#define ascendset_debug_ALREADY_DEFINED
#else
#define yyset_debug ascendset_debug
#endif

#ifdef yyget_extra
#define ascendget_extra_ALREADY_DEFINED
#else
#define yyget_extra ascendget_extra
#endif

#ifdef yyset_extra
#define ascendset_extra_ALREADY_DEFINED
#else
#define yyset_extra ascendset_extra
#endif

#ifdef yyget_in
#define ascendget_in_ALREADY_DEFINED
#else
#define yyget_in ascendget_in
#endif

#ifdef yyset_in
#define ascendset_in_ALREADY_DEFINED
#else
#define yyset_in ascendset_in
#endif

#ifdef yyget_out
#define ascendget_out_ALREADY_DEFINED
#else
#define yyget_out ascendget_out
#endif

#ifdef yyset_out
#define ascendset_out_ALREADY_DEFINED
#else
#define yyset_out ascendset_out
#endif

#ifdef yyget_leng
#define ascendget_leng_ALREADY_DEFINED
#else
#define yyget_leng ascendget_leng
#endif

#ifdef yyget_text
#define ascendget_text_ALREADY_DEFINED
#else
#define yyget_text ascendget_text
#endif

#ifdef yyget_lineno
#define ascendget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno ascendget_lineno
#endif

#ifdef yyset_lineno
#define ascendset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno ascendset_lineno
#endif

#ifdef yyget_column
#define ascendget_column_ALREADY_DEFINED
#else
#define yyget_column ascendget_column
#endif

#ifdef yyset_column
#define ascendset_column_ALREADY_DEFINED
#else
#define yyset_column ascendset_column
#endif

#ifdef yywrap
#define ascendwrap_ALREADY_DEFINED
#else
#define yywrap ascendwrap
#endif

#ifdef yyget_lval
#define ascendget_lval_ALREADY_DEFINED
#else
#define yyget_lval ascendget_lval
#endif

#ifdef yyset_lval
#define ascendset_lval_ALREADY_DEFINED
#else
#define yyset_lval ascendset_lval
#endif

#ifdef yyalloc
#define ascendalloc_ALREADY_DEFINED
#else
#define yyalloc ascendalloc
#endif

#ifdef yyrealloc
#define ascendrealloc_ALREADY_DEFINED
#else
#define yyrealloc ascendrealloc
#endif

#ifdef yyfree
#define ascendfree_ALREADY_DEFINED
#else
#define yyfree ascendfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define ascendwrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 38
#define YY_END_OF_BUFFER 39
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[487] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   11,   11,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   20,   20,    0,    0,    0,    0,   39,   37,
       35,   35,   35,   35,   37,   37,   37,   37,   35,   37,
       37,   37,   37,   35,   35,   35,   14,   14,   15,   15,
       16,   16,   37,   37,   35,   35,   35,   35,   35,   37,
       35,   35,   35,   37,   37,   11,   11,   35,   35,   35,
       35,   35,   35,   37,   35,   35,   35,   35,   35,   35,

       35,   30,   30,   30,   30,   30,   30,   32,   32,   32,
       37,   20,   20,   20,   20,   20,   20,   37,   35,   35,
       35,   37,   37,   37,   35,   35,   35,   37,   37,   35,
        0,   35,    0,    0,    0,    0,    0,    0,   36,    0,
        0,    0,    0,   34,   12,    0,   14,   15,   16,    0,
        0,   18,   18,   10,   10,   10,   10,   10,   10,   10,
       11,   22,   23,   35,    0,   26,   27,   28,   35,   30,
       30,   30,   30,   30,   30,   30,   32,    0,   20,   20,
       20,   20,   20,   20,   20,    9,    9,    9,    9,    9,
        9,    9,    8,    8,    8,    8,    8,    8,    8,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,   13,
       12,   35,   14,   15,   16,    0,    0,   10,   10,   10,
       10,   10,   35,    0,    0,   30,   30,   30,   32,    0,
       20,   20,   20,    9,    9,    9,    9,    9,    8,    8,
        8,    8,    8,    0,    0,    0,    0,    5,    0,    4,
        0,   36,    0,   12,   14,   15,   16,    0,   19,   10,
       10,   10,   10,   10,   24,    0,    0,   30,   30,   30,
       32,    0,   20,   20,   20,    9,    9,    9,    9,    9,
        8,    8,    8,    8,    8,   21,    1,    0,    0,    0,
        0,    5,    0,    4,    0,   12,   14,   15,   16,    0,

       10,   10,   10,   25,    0,   30,   32,    0,   20,    9,
        9,    9,    8,    8,    8,    8,    7,    0,    0,    0,
        0,   12,   14,   15,   16,    0,   10,   10,   10,    0,
       32,   33,    9,    9,    9,    8,    8,    8,    6,    0,
        0,    0,   12,   14,   16,   17,   10,   10,    0,   32,
        9,    9,    8,    8,    3,    0,    0,   12,   14,   16,
       10,   10,    0,   32,    9,    9,    8,    8,    2,    0,
       14,   16,   10,   10,    0,    9,    9,    8,    8,    0,
       14,   16,   10,   10,    0,    9,    9,    8,    8,    0,
       10,   10,    0,    9,    9,    8,    8,    0,   10,   10,

        0,    9,    9,    8,    8,    0,   10,   10,    0,    9,
        9,    8,    8,    0,   10,   10,    0,    9,    9,    8,
        8,    0,   10,   10,    0,    9,    9,    8,    8,    0,
       10,   10,    0,    9,    9,    8,    8,    0,   10,   10,
        0,    9,    9,    8,    8,    0,   10,   10,    0,    9,
        9,    8,    8,    0,   10,   10,    0,    9,    9,    8,
        8,    0,   10,   10,    0,    9,    9,    8,    8,    0,
        0,   31,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   29,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    1,    1,    1,    1,    1,    6,
        1,    1,    1,    1,    7,    1,    8,    9,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   11,    1,    1,
        1,    1,    1,    1,   12,   13,   14,   15,   16,   13,
       17,   18,   19,   17,   17,   20,   21,   22,   23,   24,
       17,   25,   26,   27,   28,   29,   30,   31,   17,   17,
       32,    1,   33,    1,   34,    1,   35,   13,   36,   13,

       37,   13,   17,   38,   39,   17,   40,   41,   42,   43,
       44,   45,   17,   17,   46,   47,   48,   17,   17,   49,
       50,   17,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[51] =
    {   0,
        1,    2,    3,    4,    1,    5,    1,    6,    7,    7,
        8,    7,    7,    7,    7,    7,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
       10,    1,    1,    9,    7,    7,    7,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,   10,    9
    } ;

static const flex_int16_t yy_base[577] =
    {   0,
        0,   39,   82,    0,  121,  144,  167,  190,  213,  236,
        2,   41,  264,    0,  293,  332,  371,  394,  417,  440,
      463,  486,  509,  532,   84,   97,  555,  578,  601,  624,
      647,  670,  118,  141,  700,  746,  163,  165,  789,    0,
      186,  188,  824,  869,  911,  953,  995, 1037,  658, 3539,
        9,   10,  618,  625,    4,  635,  635,  626,  599,  609,
        3,    0,   10,   12,   19,  597,   36,   12,   68,   70,
       72,   79,    0,  639,   53,   74,  607,  614,  591,    0,
     1076,   76,  177,  601,   71,   94,  129,  131,  152,  154,
      175,  221,  230,  597,  232,  238,  240,  244,  246,  248,

      600,    0, 1117,  176,  234,  594,   81,  178,  233,  582,
      236,    0, 1158,  238,  241,  592,  197,    0, 1199,  261,
      264,  591,  224,    0, 1240,  263,  267,  588,  250,    0,
        0,  576,  604,  597,  601,  605,  584,  596, 3539,  567,
      567,  570,  602,  308,    0,    0,  310,  312,  314,    0,
      602,    0,  558,    0, 1281,    0,    0,  557,  555,  558,
        0,    0,    0,  316,  557,    0,    0,    0,  550,    0,
      266,  300,    0,  550,  550,  553,    0,  547,    0,  301,
      302,    0,  544,  544,  547,    0, 1310,    0,    0,  537,
      537,  540,    0, 1339,    0,    0,  534,  532,  535,  539,

      559,  567,  566,  543,  554,  541,  530,  526,  524, 3539,
        0,    0,  325,  329,  343,    0,  556,    0, 1368,  522,
      518,  518,  345,  517,  507,  515,  511,  513,    0,  512,
      509,  505,  507,    0, 1397,  506,  498,  500,    0, 1426,
      499,  495,  495,  520,  505,  337,  119,    0,  510,  350,
      481,  516,  515,    0,  349,  353,  355,    0, 3539,    0,
     1455,  476,  511,  510,    0,  509,  478,  467,  502,  501,
        0,  505,  461,  496,  495,    0, 1484,  458,  493,  492,
        0, 1513,  453,  488,  487, 3539, 3539,  475,  464,  477,
      469,  359,  477,  364,  440,    0,  363,  368,  373,  452,

        0, 1542,  438, 3539,  479,  436,    0,    0,  435,    0,
     1571,  434,    0, 1600,  431,    0, 3539,  449,  446,  455,
      449,    0,  375,    0,  379,  457,    0, 1629,    0,  432,
        0,    0,    0, 1658,    0,    0, 1687,    0, 3539,  459,
      436,  439,    0,  381,  383, 3539,    0, 1716,  418,    0,
        0, 1745,    0, 1774, 3539,  453,  431,    0,  388,  390,
        0, 1803,  454,    0,    0, 1832,    0, 1861, 3539,  430,
      396,  398,    0, 1890,  419,    0, 1919,    0, 1948,  419,
        0,    0,    0, 1977,  405,    0, 2006,    0, 2035,  436,
        0, 2064,  399,    0, 2093,    0, 2122,  426,    0, 2151,

      407,    0, 2180,    0, 2209,  417,    0, 2238,  398,    0,
     2267,    0, 2296,  415,    0, 2325,  393,    0, 2354,    0,
     2383,  426,    0, 2412,  389,    0, 2441,    0, 2470,  431,
        0, 2499,  430,    0, 2528,    0, 2557,  395,    0, 2586,
      383,    0, 2615,    0, 2644,  391,    0, 2673,  384,    0,
     2702,    0, 2731,  375,    0, 2760,  418,    0, 2789,    0,
     2818,  378, 3539,    0,  375, 3539,    0, 3539,    0,  377,
      375, 3539,  380,  378,  376,  408,  375,  359,  333,  295,
      323,  246,  247,  280, 3539, 3539, 2855, 2865, 2875, 2885,
     2895, 2905, 2909, 2916, 2920,  263, 2924, 2934, 2944, 2948,

     2958, 2968, 2978,  255,  227,  188, 2988,  186, 2998, 3008,
      179,  166,  163, 3018,  160, 3028, 3038,  151,  140, 3048,
      128, 3058, 3068,   94, 3078,   86, 3088, 3098, 3108,   55,
     3118,   53, 3128, 3138,   32, 3148,   16, 3158, 3168, 3178,
     3188, 3198, 3208, 3218, 3228, 3238, 3248, 3258, 3268, 3278,
     3288, 3298, 3308, 3318, 3328, 3338, 3348, 3358, 3368, 3378,
     3388, 3398, 3408, 3418, 3428, 3438, 3448, 3458, 3468, 3478,
     3488, 3498, 3508, 3518, 3528,    1
    } ;

static const flex_int16_t yy_def[577] =
    {   0,
      487,  487,  487,    3,    2,    2,    2,    2,    2,    2,
        2,    2,    2,   13,  488,  488,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,  489,  489,    2,    2,    3,   39,
        2,    2,  490,  490,  491,  491,  492,  492,  486,  486,
      493,  493,   52,   52,  486,  486,  486,  486,   52,  486,
      486,  494,  486,  495,  495,   65,   52,   52,   67,   52,
       67,   52,  496,  486,  497,  497,   76,   76,   76,  498,
      498,   81,   81,  498,  498,   67,   52,   67,   52,   67,
       52,   67,   52,  486,   67,   52,   67,   52,   67,   52,

       52,  499,  499,  103,  103,  499,  499,  500,  500,  109,
      486,  501,  501,  113,  113,  501,  501,  502,  502,  119,
      119,  502,  502,  503,  503,  125,  125,  503,  503,   52,
       52,   52,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  494,  486,  504,  505,   52,   52,   52,  506,
      486,   52,   52,  507,  507,  155,  507,  507,  507,  507,
       87,   52,   52,   52,  486,   52,   52,   52,   52,  499,
      103,  103,  499,  499,  499,  499,  508,  486,  501,  113,
      113,  501,  501,  501,  501,  509,  509,  187,  509,  509,
      509,  509,  510,  510,  194,  510,  510,  510,  510,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      511,  512,   52,   52,   52,  513,  486,  514,  514,  514,
      514,  514,   52,  486,  486,  499,  499,  499,  515,  486,
      501,  501,  501,  516,  516,  516,  516,  516,  517,  517,
      517,  517,  517,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  518,   52,   52,   52,  519,  486,  520,
      520,  520,  520,  520,   52,  486,  486,  499,  499,  499,
      521,  486,  501,  501,  501,  522,  522,  522,  522,  522,
      523,  523,  523,  523,  523,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  524,   52,   52,   52,  486,

      525,  525,  525,  486,  486,  499,  526,  527,  501,  528,
      528,  528,  529,  529,  529,  529,  486,  486,  486,  486,
      486,  530,   52,   52,   52,  486,  531,  531,  531,  486,
      532,  527,  533,  533,  533,  534,  534,  534,  486,  486,
      486,  486,  535,   52,   52,  486,  536,  536,  486,  537,
      538,  538,  539,  539,  486,  486,  486,   52,   52,   52,
      540,  540,  486,   52,  541,  541,  542,  542,  486,  486,
       52,   52,  543,  543,  486,  544,  544,  545,  545,  486,
       52,   52,  546,  546,  486,  547,  547,  548,  548,  486,
      549,  549,  486,  550,  550,  551,  551,  486,  552,  552,

      486,  553,  553,  554,  554,  486,  555,  555,  486,  556,
      556,  557,  557,  486,  558,  558,  486,  559,  559,  560,
      560,  486,  561,  561,  486,  562,  562,  563,  563,  486,
      564,  564,  486,  565,  565,  566,  566,  486,  567,  567,
      486,  568,  568,  569,  569,  486,  570,  570,  486,  571,
      571,  572,  572,  486,  573,  573,  486,  574,  574,  575,
      575,  486,  486,  576,  486,  486,  576,  486,  576,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,    0,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486
    } ;

static const flex_int16_t yy_nxt[3590] =
    {   0,
      486,  486,  486,  486,  486,  486,  292,  130,   51,   52,
      292,   52,   52,   52,   53,   54,   52,   52,  144,  144,
      147,  147,  364,   55,   56,   50,   50,  134,  135,   57,
       58,   50,   50,   73,   59,   52,   52,  141,  358,  131,
      486,  142,  146,   60,  147,  147,   61,   51,   52,  486,
       52,   52,   52,   53,   54,   52,   52,  131,  486,  350,
      146,  343,   55,   56,   50,   50,  131,  486,   57,   58,
       50,   50,   73,   59,   52,   52,  148,  148,  148,  148,
      149,  149,   60,  131,  131,   61,   62,  149,  149,   63,
       64,   65,  331,   65,   65,   65,   65,   65,   52,   52,

      322,  131,  161,  161,  486,  159,  154,   50,   50,  160,
       94,   52,   52,   50,   50,  175,   66,   65,   65,  176,
       50,   50,  486,   94,  154,   60,   50,   50,   61,   67,
       68,  101,   52,   52,  307,   52,   52,  161,  161,  162,
      162,   50,   50,  290,   50,   50,  300,   50,   50,  291,
       50,   50,   67,   68,  101,   52,   52,  296,   52,   52,
      162,  162,  163,  163,   50,   50,  271,   50,   50,  258,
       50,   50,  145,   50,   50,   69,   70,   52,   52,   52,
       52,   52,   52,  163,  163,  254,   50,   50,   50,   50,
       50,   50,  229,   50,  216,   50,   50,   50,   69,   70,

       52,   52,   52,   52,   52,   52,  170,  154,  131,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   71,   72,  157,  170,  154,  131,   52,   52,  164,
      164,  184,  111,  212,  111,  185,   50,   50,  164,  164,
      166,  166,   50,   50,   71,   72,  166,  166,  167,  167,
       52,   52,  167,  167,  168,  168,  168,  168,  191,   50,
       50,  211,  192,  486,  170,   50,   50,   74,  179,  150,
      141,  179,   75,   76,  142,   76,   76,   76,   77,   78,
      173,  486,  170,  485,  198,  178,  179,  182,  199,  179,
      484,  186,  483,  193,  186,   73,  170,  193,   79,   76,

       76,   81,   82,   50,   82,   82,   82,   82,   82,  186,
      189,  193,  186,  196,  170,  193,  144,  144,  213,  213,
      214,  214,  215,  215,  223,  223,  482,   83,   82,   82,
      170,  179,  179,  255,  255,  481,   84,  256,  256,   85,
       81,   82,   50,   82,   82,   82,   82,   82,  170,  179,
      179,  257,  257,  265,  265,  288,  294,  297,  297,  289,
      294,  298,  298,  299,  299,  292,   83,   82,   82,  292,
      294,  323,  323,  480,  294,   84,  324,  324,   85,   86,
       87,  325,  325,  344,  344,   52,   52,  345,  345,  359,
      359,  360,  360,  479,   50,   50,  371,  371,  372,  372,

       50,   50,   86,   87,  381,  381,  382,  382,   52,   52,
      478,  477,  476,  475,  474,  473,  472,   50,   50,  471,
      470,  465,  462,   50,   50,   88,   89,  457,  454,  449,
      446,   52,   52,  441,  438,  433,  430,  425,  422,  417,
       50,   50,  414,  409,  406,  401,   50,   50,   88,   89,
      398,  393,  390,  385,   52,   52,  380,  375,  370,  369,
      363,  357,  356,   50,   50,  355,  349,  346,  342,   50,
       50,   90,   91,  341,  340,  339,  338,   52,   52,  335,
      182,  173,  330,  329,  326,  139,   50,   50,  321,  320,
      319,  318,   50,   50,   90,   91,  317,  316,  316,  315,

       52,   52,  139,  139,  312,  182,  182,  309,  308,   50,
       50,  173,  173,  306,  305,   50,   50,   92,   93,  304,
      139,  139,  303,   52,   52,  139,  139,  295,  293,  287,
      286,  285,   50,   50,  284,  283,  280,  279,   50,   50,
       92,   93,  278,  275,  274,  273,   52,   52,  272,  270,
      269,  268,  267,  266,  264,   50,   50,  263,  262,  259,
      253,   50,   50,   95,   96,  252,  251,  250,  249,   52,
       52,  248,  247,  246,  245,  244,  243,  242,   50,   50,
      241,  238,  237,  236,   50,   50,   95,   96,  233,  232,
      231,  230,   52,   52,  228,  227,  226,  225,  224,  222,

      221,   50,   50,  220,  200,  217,  210,   50,   50,   97,
       98,  209,  208,  207,  206,   52,   52,  205,  204,  203,
      202,  201,  200,  197,   50,   50,  190,  183,  139,  174,
       50,   50,   97,   98,  169,  165,  158,  139,   52,   52,
      133,  153,  151,  139,  140,  139,  138,   50,   50,  137,
      136,  133,  132,   50,   50,   99,  100,  486,  486,  486,
      486,   52,   52,  486,  486,  486,  486,  486,  486,  486,
       50,   50,  486,  486,  486,  486,   50,   50,   99,  100,
      486,  486,  486,  486,   52,   52,  486,  486,  486,  486,
      486,  486,  486,   50,   50,  486,  486,  486,  486,   50,

       50,   50,   50,   50,  486,  486,  486,  486,  103,  104,
      486,  104,  104,  104,  104,  104,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  105,  104,  104,  486,  486,  486,
      486,  486,  486,  106,  486,  486,  107,   50,   50,   50,
      486,  486,  486,  486,  103,  104,  486,  104,  104,  104,
      104,  104,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      105,  104,  104,  486,  486,  486,  486,  486,  486,  106,
      486,  486,  107,   50,  486,  486,   50,  108,  109,  486,

      109,  109,  109,  109,  109,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  110,  109,  109,   50,  486,  486,  486,
      486,  486,  113,  114,  486,  114,  114,  114,  114,  114,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  115,  114,
      114,  486,  486,  486,  486,  486,  486,  116,  486,  486,
      117,   50,  486,  486,  486,  486,  486,  113,  114,  486,
      114,  114,  114,  114,  114,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  115,  114,  114,  486,  486,  486,  486,
      486,  486,  116,  486,  486,  117,   50,  486,   50,  119,
      120,   50,  120,  120,  120,  120,  120,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  121,  120,  120,  486,  486,
      486,  486,  486,  486,  122,  486,  486,  123,   50,  486,
       50,  119,  120,   50,  120,  120,  120,  120,  120,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  121,  120,  120,
      486,  486,  486,  486,  486,  486,  122,  486,  486,  123,

       50,  486,  486,  125,  126,  486,  126,  126,  126,  126,
      126,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  127,
      126,  126,  486,  486,  486,  486,  486,  486,  128,  486,
      486,  129,   50,  486,  486,  125,  126,  486,  126,  126,
      126,  126,  126,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  127,  126,  126,  486,  486,  486,  486,  486,  486,
      128,  486,  486,  129,  155,  155,  486,  155,  155,  155,
      155,  155,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  156,  486,  486,  486,
      155,  155,  155,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  156,  171,  171,  486,  171,  171,
      171,  171,  171,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  172,  486,  486,
      486,  171,  171,  171,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  172,  180,  180,  486,  180,
      180,  180,  180,  180,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  181,  486,
      486,  486,  180,  180,  180,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  181,  187,  187,  486,
      187,  187,  187,  187,  187,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  188,
      486,  486,  486,  187,  187,  187,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  188,  194,  194,
      486,  194,  194,  194,  194,  194,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      195,  486,  486,  486,  194,  194,  194,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  195,  219,
      219,  486,  219,  219,  219,  219,  219,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  219,  219,  219,  235,  235,
      486,  235,  235,  235,  235,  235,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  235,  235,  235,  240,  240,  486,
      240,  240,  240,  240,  240,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  240,  240,  240,  261,  261,  486,  261,
      261,  261,  261,  261,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  261,  261,  261,  277,  277,  486,  277,  277,
      277,  277,  277,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  277,  277,  277,  282,  282,  486,  282,  282,  282,
      282,  282,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      282,  282,  282,  302,  302,  486,  302,  302,  302,  302,
      302,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  302,
      302,  302,  311,  311,  486,  311,  311,  311,  311,  311,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  311,  311,
      311,  314,  314,  486,  314,  314,  314,  314,  314,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  314,  314,  314,
      328,  328,  486,  328,  328,  328,  328,  328,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  328,  328,  328,  334,
      334,  486,  334,  334,  334,  334,  334,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  334,  334,  334,  337,  337,
      486,  337,  337,  337,  337,  337,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  337,  337,  337,  348,  348,  486,
      348,  348,  348,  348,  348,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  348,  348,  348,  352,  352,  486,  352,
      352,  352,  352,  352,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  352,  352,  352,  354,  354,  486,  354,  354,

      354,  354,  354,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  354,  354,  354,  362,  362,  486,  362,  362,  362,
      362,  362,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      362,  362,  362,  366,  366,  486,  366,  366,  366,  366,
      366,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  366,
      366,  366,  368,  368,  486,  368,  368,  368,  368,  368,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  368,  368,
      368,  374,  374,  486,  374,  374,  374,  374,  374,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  374,  374,  374,
      377,  377,  486,  377,  377,  377,  377,  377,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  377,  377,  377,  379,
      379,  486,  379,  379,  379,  379,  379,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  379,  379,  379,  384,  384,

      486,  384,  384,  384,  384,  384,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  384,  384,  384,  387,  387,  486,
      387,  387,  387,  387,  387,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  387,  387,  387,  389,  389,  486,  389,
      389,  389,  389,  389,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  389,  389,  389,  392,  392,  486,  392,  392,
      392,  392,  392,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  392,  392,  392,  395,  395,  486,  395,  395,  395,
      395,  395,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      395,  395,  395,  397,  397,  486,  397,  397,  397,  397,
      397,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  397,
      397,  397,  400,  400,  486,  400,  400,  400,  400,  400,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  400,  400,

      400,  403,  403,  486,  403,  403,  403,  403,  403,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  403,  403,  403,
      405,  405,  486,  405,  405,  405,  405,  405,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  405,  405,  405,  408,
      408,  486,  408,  408,  408,  408,  408,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  408,  408,  408,  411,  411,
      486,  411,  411,  411,  411,  411,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  411,  411,  411,  413,  413,  486,
      413,  413,  413,  413,  413,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  413,  413,  413,  416,  416,  486,  416,
      416,  416,  416,  416,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  416,  416,  416,  419,  419,  486,  419,  419,
      419,  419,  419,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  419,  419,  419,  421,  421,  486,  421,  421,  421,
      421,  421,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      421,  421,  421,  424,  424,  486,  424,  424,  424,  424,
      424,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  424,
      424,  424,  427,  427,  486,  427,  427,  427,  427,  427,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  427,  427,
      427,  429,  429,  486,  429,  429,  429,  429,  429,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  429,  429,  429,
      432,  432,  486,  432,  432,  432,  432,  432,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  432,  432,  432,  435,
      435,  486,  435,  435,  435,  435,  435,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  435,  435,  435,  437,  437,
      486,  437,  437,  437,  437,  437,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  437,  437,  437,  440,  440,  486,
      440,  440,  440,  440,  440,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  440,  440,  440,  443,  443,  486,  443,
      443,  443,  443,  443,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  443,  443,  443,  445,  445,  486,  445,  445,
      445,  445,  445,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  445,  445,  445,  448,  448,  486,  448,  448,  448,

      448,  448,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      448,  448,  448,  451,  451,  486,  451,  451,  451,  451,
      451,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  451,
      451,  451,  453,  453,  486,  453,  453,  453,  453,  453,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  453,  453,
      453,  456,  456,  486,  456,  456,  456,  456,  456,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,

      486,  486,  486,  486,  486,  486,  486,  456,  456,  456,
      459,  459,  486,  459,  459,  459,  459,  459,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  459,  459,  459,  461,
      461,  486,  461,  461,  461,  461,  461,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  461,  461,  461,  464,  464,
      486,  464,  464,  464,  464,  464,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  464,  464,  464,  467,  467,  486,

      467,  467,  467,  467,  467,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  467,  467,  467,  469,  469,  486,  469,
      469,  469,  469,  469,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  469,  469,  469,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,   80,   80,   80,   80,   80,
       80,   80,   80,   80,   80,  102,  102,  102,  102,  102,
      102,  102,  102,  102,  102,  112,  112,  112,  112,  112,
      112,  112,  112,  112,  112,  118,  118,  118,  118,  118,

      118,  118,  118,  118,  118,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  124,  130,  486,  486,  130,  143,
      486,  486,  143,  486,  143,  143,  145,  486,  486,  145,
      152,  486,  486,  152,  154,  154,  154,  154,  154,  154,
      154,  486,  154,  154,  170,  486,  486,  486,  170,  170,
      170,  170,  170,  170,  177,  486,  486,  177,  179,  179,
      486,  179,  179,  179,  179,  179,  179,  179,  186,  186,
      186,  186,  486,  486,  186,  486,  186,  186,  193,  193,
      193,  193,  486,  193,  193,  193,  193,  193,  218,  218,
      218,  218,  218,  218,  218,  486,  218,  218,  234,  234,

      234,  234,  486,  486,  234,  486,  234,  234,  239,  239,
      239,  239,  486,  239,  239,  239,  239,  239,  260,  260,
      260,  260,  260,  260,  260,  486,  260,  260,  276,  276,
      276,  276,  486,  486,  276,  486,  276,  276,  281,  281,
      281,  281,  486,  281,  281,  281,  281,  281,  301,  301,
      301,  301,  301,  301,  301,  486,  301,  301,  310,  310,
      310,  310,  486,  486,  310,  486,  310,  310,  313,  313,
      313,  313,  486,  313,  313,  313,  313,  313,  327,  327,
      327,  327,  327,  327,  327,  486,  327,  327,  332,  486,
      486,  486,  332,  332,  332,  332,  332,  332,  333,  333,

      333,  333,  486,  486,  333,  486,  333,  333,  336,  336,
      336,  336,  486,  336,  336,  336,  336,  336,  347,  347,
      347,  347,  347,  347,  347,  486,  347,  347,  351,  351,
      351,  351,  486,  486,  351,  486,  351,  351,  353,  353,
      353,  353,  486,  353,  353,  353,  353,  353,  361,  361,
      361,  361,  361,  361,  361,  486,  361,  361,  365,  365,
      365,  365,  486,  486,  365,  486,  365,  365,  367,  367,
      367,  367,  486,  367,  367,  367,  367,  367,  373,  373,
      373,  373,  373,  373,  373,  486,  373,  373,  376,  376,
      376,  376,  486,  486,  376,  486,  376,  376,  378,  378,

      378,  378,  486,  378,  378,  378,  378,  378,  383,  383,
      383,  383,  383,  383,  383,  486,  383,  383,  386,  386,
      386,  386,  486,  486,  386,  486,  386,  386,  388,  388,
      388,  388,  486,  388,  388,  388,  388,  388,  391,  391,
      391,  391,  391,  391,  391,  486,  391,  391,  394,  394,
      394,  394,  486,  486,  394,  486,  394,  394,  396,  396,
      396,  396,  486,  396,  396,  396,  396,  396,  399,  399,
      399,  399,  399,  399,  399,  486,  399,  399,  402,  402,
      402,  402,  486,  486,  402,  486,  402,  402,  404,  404,
      404,  404,  486,  404,  404,  404,  404,  404,  407,  407,

      407,  407,  407,  407,  407,  486,  407,  407,  410,  410,
      410,  410,  486,  486,  410,  486,  410,  410,  412,  412,
      412,  412,  486,  412,  412,  412,  412,  412,  415,  415,
      415,  415,  415,  415,  415,  486,  415,  415,  418,  418,
      418,  418,  486,  486,  418,  486,  418,  418,  420,  420,
      420,  420,  486,  420,  420,  420,  420,  420,  423,  423,
      423,  423,  423,  423,  423,  486,  423,  423,  426,  426,
      426,  426,  486,  486,  426,  486,  426,  426,  428,  428,
      428,  428,  486,  428,  428,  428,  428,  428,  431,  431,
      431,  431,  431,  431,  431,  486,  431,  431,  434,  434,

      434,  434,  486,  486,  434,  486,  434,  434,  436,  436,
      436,  436,  486,  436,  436,  436,  436,  436,  439,  439,
      439,  439,  439,  439,  439,  486,  439,  439,  442,  442,
      442,  442,  486,  486,  442,  486,  442,  442,  444,  444,
      444,  444,  486,  444,  444,  444,  444,  444,  447,  447,
      447,  447,  447,  447,  447,  486,  447,  447,  450,  450,
      450,  450,  486,  486,  450,  486,  450,  450,  452,  452,
      452,  452,  486,  452,  452,  452,  452,  452,  455,  455,
      455,  455,  455,  455,  455,  486,  455,  455,  458,  458,
      458,  458,  486,  486,  458,  486,  458,  458,  460,  460,

      460,  460,  486,  460,  460,  460,  460,  460,  463,  463,
      463,  463,  463,  463,  463,  486,  463,  463,  466,  466,
      466,  466,  486,  486,  466,  486,  466,  466,  468,  468,
      468,  468,  486,  468,  468,  468,  468,  468,   49,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486
    } ;

static const flex_int16_t yy_chk[3590] =
    {   0,
        0,    0,    0,    0,    0,    0,  248,  576,    1,    1,
      248,    1,    1,    1,    1,    1,   11,   11,   63,   63,
       68,   68,  537,    1,    1,   11,   11,   55,   55,    1,
        1,   11,   11,   11,    1,    1,    1,   61,  535,   51,
       52,   61,   64,    1,   67,   67,    1,    2,    2,   65,
        2,    2,    2,    2,    2,   12,   12,   51,   52,  532,
       64,  530,    2,    2,   12,   12,   67,   65,    2,    2,
       12,   12,   12,    2,    2,    2,   69,   69,   70,   70,
       71,   71,    2,   75,   67,    2,    3,   72,   72,    3,
        3,    3,  526,    3,    3,    3,    3,    3,   25,   25,

      524,   75,   86,   86,   76,   85,   82,   25,   25,   85,
       25,   26,   26,   25,   25,  107,    3,    3,    3,  107,
       26,   26,   76,   26,   82,    3,   26,   26,    3,    5,
        5,   33,   33,   33,  521,    5,    5,   87,   87,   88,
       88,   33,   33,  247,    5,    5,  519,   33,   33,  247,
        5,    5,    6,    6,   34,   34,   34,  518,    6,    6,
       89,   89,   90,   90,   34,   34,  515,    6,    6,  513,
       34,   34,  512,    6,    6,    7,    7,   37,   37,   38,
       38,    7,    7,   91,   91,  511,   37,   37,   38,   38,
        7,    7,  508,   37,  506,   38,    7,    7,    8,    8,

       41,   41,   42,   42,    8,    8,  104,   83,  108,   41,
       41,   42,   42,    8,    8,   41,   41,   42,   42,    8,
        8,    9,    9,   83,  104,   83,  108,    9,    9,   92,
       92,  117,   41,  505,   42,  117,    9,    9,   93,   93,
       95,   95,    9,    9,   10,   10,   96,   96,   97,   97,
       10,   10,   98,   98,   99,   99,  100,  100,  123,   10,
       10,  504,  123,  109,  105,   10,   10,   13,  114,  496,
      111,  115,   13,   13,  111,   13,   13,   13,   13,   13,
      105,  109,  105,  484,  129,  111,  114,  115,  129,  115,
      483,  120,  482,  126,  121,   13,  171,  127,   13,   13,

       13,   15,   15,   15,   15,   15,   15,   15,   15,  120,
      121,  126,  121,  127,  171,  127,  144,  144,  147,  147,
      148,  148,  149,  149,  164,  164,  481,   15,   15,   15,
      172,  180,  181,  213,  213,  480,   15,  214,  214,   15,
       16,   16,   16,   16,   16,   16,   16,   16,  172,  180,
      181,  215,  215,  223,  223,  246,  250,  255,  255,  246,
      250,  256,  256,  257,  257,  292,   16,   16,   16,  292,
      294,  297,  297,  479,  294,   16,  298,  298,   16,   17,
       17,  299,  299,  323,  323,   17,   17,  325,  325,  344,
      344,  345,  345,  478,   17,   17,  359,  359,  360,  360,

       17,   17,   18,   18,  371,  371,  372,  372,   18,   18,
      477,  476,  475,  474,  473,  471,  470,   18,   18,  465,
      462,  457,  454,   18,   18,   19,   19,  449,  446,  441,
      438,   19,   19,  433,  430,  425,  422,  417,  414,  409,
       19,   19,  406,  401,  398,  393,   19,   19,   20,   20,
      390,  385,  380,  375,   20,   20,  370,  363,  357,  356,
      349,  342,  341,   20,   20,  340,  330,  326,  321,   20,
       20,   21,   21,  320,  319,  318,  315,   21,   21,  312,
      309,  306,  305,  303,  300,  295,   21,   21,  293,  291,
      290,  289,   21,   21,   22,   22,  288,  285,  284,  283,

       22,   22,  280,  279,  278,  275,  274,  273,  272,   22,
       22,  270,  269,  268,  267,   22,   22,   23,   23,  266,
      264,  263,  262,   23,   23,  253,  252,  251,  249,  245,
      244,  243,   23,   23,  242,  241,  238,  237,   23,   23,
       24,   24,  236,  233,  232,  231,   24,   24,  230,  228,
      227,  226,  225,  224,  222,   24,   24,  221,  220,  217,
      209,   24,   24,   27,   27,  208,  207,  206,  205,   27,
       27,  204,  203,  202,  201,  200,  199,  198,   27,   27,
      197,  192,  191,  190,   27,   27,   28,   28,  185,  184,
      183,  178,   28,   28,  176,  175,  174,  169,  165,  160,

      159,   28,   28,  158,  153,  151,  143,   28,   28,   29,
       29,  142,  141,  140,  138,   29,   29,  137,  136,  135,
      134,  133,  132,  128,   29,   29,  122,  116,  110,  106,
       29,   29,   30,   30,  101,   94,   84,   79,   30,   30,
       78,   77,   74,   66,   60,   59,   58,   30,   30,   57,
       56,   54,   53,   30,   30,   31,   31,   49,    0,    0,
        0,   31,   31,    0,    0,    0,    0,    0,    0,    0,
       31,   31,    0,    0,    0,    0,   31,   31,   32,   32,
        0,    0,    0,    0,   32,   32,    0,    0,    0,    0,
        0,    0,    0,   32,   32,    0,    0,    0,    0,   32,

       32,   35,   35,   35,    0,    0,    0,    0,   35,   35,
        0,   35,   35,   35,   35,   35,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   35,   35,   35,    0,    0,    0,
        0,    0,    0,   35,    0,    0,   35,   36,   36,   36,
        0,    0,    0,    0,   36,   36,    0,   36,   36,   36,
       36,   36,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       36,   36,   36,    0,    0,    0,    0,    0,    0,   36,
        0,    0,   36,   39,    0,    0,   39,   39,   39,    0,

       39,   39,   39,   39,   39,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   39,   39,   39,   43,    0,    0,    0,
        0,    0,   43,   43,    0,   43,   43,   43,   43,   43,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   43,   43,
       43,    0,    0,    0,    0,    0,    0,   43,    0,    0,
       43,   44,    0,    0,    0,    0,    0,   44,   44,    0,
       44,   44,   44,   44,   44,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,   44,   44,   44,    0,    0,    0,    0,
        0,    0,   44,    0,    0,   44,   45,    0,   45,   45,
       45,   45,   45,   45,   45,   45,   45,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   45,   45,   45,    0,    0,
        0,    0,    0,    0,   45,    0,    0,   45,   46,    0,
       46,   46,   46,   46,   46,   46,   46,   46,   46,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   46,   46,   46,
        0,    0,    0,    0,    0,    0,   46,    0,    0,   46,

       47,    0,    0,   47,   47,    0,   47,   47,   47,   47,
       47,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   47,
       47,   47,    0,    0,    0,    0,    0,    0,   47,    0,
        0,   47,   48,    0,    0,   48,   48,    0,   48,   48,
       48,   48,   48,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   48,   48,   48,    0,    0,    0,    0,    0,    0,
       48,    0,    0,   48,   81,   81,    0,   81,   81,   81,
       81,   81,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,   81,    0,    0,    0,
       81,   81,   81,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   81,  103,  103,    0,  103,  103,
      103,  103,  103,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  103,    0,    0,
        0,  103,  103,  103,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  103,  113,  113,    0,  113,
      113,  113,  113,  113,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  113,    0,
        0,    0,  113,  113,  113,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  113,  119,  119,    0,
      119,  119,  119,  119,  119,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  119,
        0,    0,    0,  119,  119,  119,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  119,  125,  125,
        0,  125,  125,  125,  125,  125,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      125,    0,    0,    0,  125,  125,  125,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  125,  155,
      155,    0,  155,  155,  155,  155,  155,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  155,  155,  155,  187,  187,
        0,  187,  187,  187,  187,  187,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  187,  187,  187,  194,  194,    0,
      194,  194,  194,  194,  194,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  194,  194,  194,  219,  219,    0,  219,
      219,  219,  219,  219,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,  219,  219,  219,  235,  235,    0,  235,  235,
      235,  235,  235,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  235,  235,  235,  240,  240,    0,  240,  240,  240,
      240,  240,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      240,  240,  240,  261,  261,    0,  261,  261,  261,  261,
      261,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  261,
      261,  261,  277,  277,    0,  277,  277,  277,  277,  277,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  277,  277,
      277,  282,  282,    0,  282,  282,  282,  282,  282,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  282,  282,  282,
      302,  302,    0,  302,  302,  302,  302,  302,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  302,  302,  302,  311,
      311,    0,  311,  311,  311,  311,  311,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,  311,  311,  311,  314,  314,
        0,  314,  314,  314,  314,  314,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  314,  314,  314,  328,  328,    0,
      328,  328,  328,  328,  328,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  328,  328,  328,  334,  334,    0,  334,
      334,  334,  334,  334,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  334,  334,  334,  337,  337,    0,  337,  337,

      337,  337,  337,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  337,  337,  337,  348,  348,    0,  348,  348,  348,
      348,  348,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      348,  348,  348,  352,  352,    0,  352,  352,  352,  352,
      352,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  352,
      352,  352,  354,  354,    0,  354,  354,  354,  354,  354,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,  354,  354,
      354,  362,  362,    0,  362,  362,  362,  362,  362,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  362,  362,  362,
      366,  366,    0,  366,  366,  366,  366,  366,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  366,  366,  366,  368,
      368,    0,  368,  368,  368,  368,  368,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  368,  368,  368,  374,  374,

        0,  374,  374,  374,  374,  374,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  374,  374,  374,  377,  377,    0,
      377,  377,  377,  377,  377,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  377,  377,  377,  379,  379,    0,  379,
      379,  379,  379,  379,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  379,  379,  379,  384,  384,    0,  384,  384,
      384,  384,  384,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  384,  384,  384,  387,  387,    0,  387,  387,  387,
      387,  387,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      387,  387,  387,  389,  389,    0,  389,  389,  389,  389,
      389,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  389,
      389,  389,  392,  392,    0,  392,  392,  392,  392,  392,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  392,  392,

      392,  395,  395,    0,  395,  395,  395,  395,  395,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  395,  395,  395,
      397,  397,    0,  397,  397,  397,  397,  397,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  397,  397,  397,  400,
      400,    0,  400,  400,  400,  400,  400,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  400,  400,  400,  403,  403,
        0,  403,  403,  403,  403,  403,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  403,  403,  403,  405,  405,    0,
      405,  405,  405,  405,  405,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  405,  405,  405,  408,  408,    0,  408,
      408,  408,  408,  408,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  408,  408,  408,  411,  411,    0,  411,  411,
      411,  411,  411,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,  411,  411,  411,  413,  413,    0,  413,  413,  413,
      413,  413,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      413,  413,  413,  416,  416,    0,  416,  416,  416,  416,
      416,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  416,
      416,  416,  419,  419,    0,  419,  419,  419,  419,  419,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  419,  419,
      419,  421,  421,    0,  421,  421,  421,  421,  421,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  421,  421,  421,
      424,  424,    0,  424,  424,  424,  424,  424,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  424,  424,  424,  427,
      427,    0,  427,  427,  427,  427,  427,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  427,  427,  427,  429,  429,
        0,  429,  429,  429,  429,  429,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,  429,  429,  429,  432,  432,    0,
      432,  432,  432,  432,  432,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  432,  432,  432,  435,  435,    0,  435,
      435,  435,  435,  435,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  435,  435,  435,  437,  437,    0,  437,  437,
      437,  437,  437,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  437,  437,  437,  440,  440,    0,  440,  440,  440,

      440,  440,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      440,  440,  440,  443,  443,    0,  443,  443,  443,  443,
      443,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  443,
      443,  443,  445,  445,    0,  445,  445,  445,  445,  445,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  445,  445,
      445,  448,  448,    0,  448,  448,  448,  448,  448,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,  448,  448,  448,
      451,  451,    0,  451,  451,  451,  451,  451,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  451,  451,  451,  453,
      453,    0,  453,  453,  453,  453,  453,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  453,  453,  453,  456,  456,
        0,  456,  456,  456,  456,  456,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  456,  456,  456,  459,  459,    0,

      459,  459,  459,  459,  459,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  459,  459,  459,  461,  461,    0,  461,
      461,  461,  461,  461,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  461,  461,  461,  487,  487,  487,  487,  487,
      487,  487,  487,  487,  487,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  489,  489,  489,  489,  489,
      489,  489,  489,  489,  489,  490,  490,  490,  490,  490,
      490,  490,  490,  490,  490,  491,  491,  491,  491,  491,

      491,  491,  491,  491,  491,  492,  492,  492,  492,  492,
      492,  492,  492,  492,  492,  493,    0,    0,  493,  494,
        0,    0,  494,    0,  494,  494,  495,    0,    0,  495,
      497,    0,    0,  497,  498,  498,  498,  498,  498,  498,
      498,    0,  498,  498,  499,    0,    0,    0,  499,  499,
      499,  499,  499,  499,  500,    0,    0,  500,  501,  501,
        0,  501,  501,  501,  501,  501,  501,  501,  502,  502,
      502,  502,    0,    0,  502,    0,  502,  502,  503,  503,
      503,  503,    0,  503,  503,  503,  503,  503,  507,  507,
      507,  507,  507,  507,  507,    0,  507,  507,  509,  509,

      509,  509,    0,    0,  509,    0,  509,  509,  510,  510,
      510,  510,    0,  510,  510,  510,  510,  510,  514,  514,
      514,  514,  514,  514,  514,    0,  514,  514,  516,  516,
      516,  516,    0,    0,  516,    0,  516,  516,  517,  517,
      517,  517,    0,  517,  517,  517,  517,  517,  520,  520,
      520,  520,  520,  520,  520,    0,  520,  520,  522,  522,
      522,  522,    0,    0,  522,    0,  522,  522,  523,  523,
      523,  523,    0,  523,  523,  523,  523,  523,  525,  525,
      525,  525,  525,  525,  525,    0,  525,  525,  527,    0,
        0,    0,  527,  527,  527,  527,  527,  527,  528,  528,

      528,  528,    0,    0,  528,    0,  528,  528,  529,  529,
      529,  529,    0,  529,  529,  529,  529,  529,  531,  531,
      531,  531,  531,  531,  531,    0,  531,  531,  533,  533,
      533,  533,    0,    0,  533,    0,  533,  533,  534,  534,
      534,  534,    0,  534,  534,  534,  534,  534,  536,  536,
      536,  536,  536,  536,  536,    0,  536,  536,  538,  538,
      538,  538,    0,    0,  538,    0,  538,  538,  539,  539,
      539,  539,    0,  539,  539,  539,  539,  539,  540,  540,
      540,  540,  540,  540,  540,    0,  540,  540,  541,  541,
      541,  541,    0,    0,  541,    0,  541,  541,  542,  542,

      542,  542,    0,  542,  542,  542,  542,  542,  543,  543,
      543,  543,  543,  543,  543,    0,  543,  543,  544,  544,
      544,  544,    0,    0,  544,    0,  544,  544,  545,  545,
      545,  545,    0,  545,  545,  545,  545,  545,  546,  546,
      546,  546,  546,  546,  546,    0,  546,  546,  547,  547,
      547,  547,    0,    0,  547,    0,  547,  547,  548,  548,
      548,  548,    0,  548,  548,  548,  548,  548,  549,  549,
      549,  549,  549,  549,  549,    0,  549,  549,  550,  550,
      550,  550,    0,    0,  550,    0,  550,  550,  551,  551,
      551,  551,    0,  551,  551,  551,  551,  551,  552,  552,

      552,  552,  552,  552,  552,    0,  552,  552,  553,  553,
      553,  553,    0,    0,  553,    0,  553,  553,  554,  554,
      554,  554,    0,  554,  554,  554,  554,  554,  555,  555,
      555,  555,  555,  555,  555,    0,  555,  555,  556,  556,
      556,  556,    0,    0,  556,    0,  556,  556,  557,  557,
      557,  557,    0,  557,  557,  557,  557,  557,  558,  558,
      558,  558,  558,  558,  558,    0,  558,  558,  559,  559,
      559,  559,    0,    0,  559,    0,  559,  559,  560,  560,
      560,  560,    0,  560,  560,  560,  560,  560,  561,  561,
      561,  561,  561,  561,  561,    0,  561,  561,  562,  562,

      562,  562,    0,    0,  562,    0,  562,  562,  563,  563,
      563,  563,    0,  563,  563,  563,  563,  563,  564,  564,
      564,  564,  564,  564,  564,    0,  564,  564,  565,  565,
      565,  565,    0,    0,  565,    0,  565,  565,  566,  566,
      566,  566,    0,  566,  566,  566,  566,  566,  567,  567,
      567,  567,  567,  567,  567,    0,  567,  567,  568,  568,
      568,  568,    0,    0,  568,    0,  568,  568,  569,  569,
      569,  569,    0,  569,  569,  569,  569,  569,  570,  570,
      570,  570,  570,  570,  570,    0,  570,  570,  571,  571,
      571,  571,    0,    0,  571,    0,  571,  571,  572,  572,

      572,  572,    0,  572,  572,  572,  572,  572,  573,  573,
      573,  573,  573,  573,  573,    0,  573,  573,  574,  574,
      574,  574,    0,    0,  574,    0,  574,  574,  575,  575,
      575,  575,    0,  575,  575,  575,  575,  575,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "ascend_scanner.l"

/*
 * We want a reentrant scanner.
 */
/*
 * We want to generate code that can be used by a reentrant parser
 * generated by Bison or Berkeley YACC.
 */
/*
 * We don't read interactively from the terminal.
 */
/*
 * We want to stop processing when we get to the end of the input.
 */
/*
 * The type for the state we keep for the scanner (and parser).
 */
/*
 * Prefix scanner routines with "ascend" rather than "yy", so this scanner
 * can coexist with other scanners.
 */
/*
 * We have to override the memory allocators so that we don't get
 * "unused argument" warnings from the yyscanner argument (which
 * we don't use, as we have a global memory allocator).
 *
 * We provide, as macros, our own versions of the routines generated by Flex,
 * which just call malloc()/realloc()/free() (as the Flex versions do),
 * discarding the extra argument.
 */
#line 52 "ascend_scanner.l"
/* ascend_scanner.l
 *
 * Wiretap Library
 * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include <stdlib.h>
#include <string.h>

#include "wtap-int.h"
#include "ascendtext.h"
#include "ascend-int.h"
#include "ascend.h"
#include "file_wrappers.h"

#define YY_INPUT(buf,result,max_size) { \
	ascend_state_t *parser_state = ascendget_extra(yyscanner); \
	int c = file_getc(parser_state->fh); \
	if (c == EOF) { \
		parser_state->err = file_error(parser_state->fh, \
		    &parser_state->err_info); \
		if (parser_state->err == 0) \
			parser_state->err = WTAP_ERR_SHORT_READ; \
		result = YY_NULL; \
	} else { \
		buf[0] = c; \
		result = 1; \
	} \
}

#define NO_USER "<none>"

#ifndef HAVE_UNISTD_H
#define YY_NO_UNISTD_H
#endif

/*
 * Sleazy hack to suppress compiler warnings in yy_fatal_error().
 */
#define YY_EXIT_FAILURE ((void)yyscanner, 2)

/*
 * Macros for the allocators, to discard the extra argument.
 */
#define ascendalloc(size, yyscanner)		(void *)malloc(size)
#define ascendrealloc(ptr, size, yyscanner)	(void *)realloc((char *)(ptr), (size))
#define ascendfree(ptr, yyscanner)		free((char *)ptr)

#line 1703 "ascend_scanner.c"

#line 1705 "ascend_scanner.c"

#define INITIAL 0
#define sc_gen_task 1
#define sc_gen_time_s 2
#define sc_gen_time_u 3
#define sc_gen_octets 4
#define sc_gen_counter 5
#define sc_gen_byte 6
#define sc_wds_user 7
#define sc_wds_sess 8
#define sc_wdd_date_d 9
#define sc_wdd_date_m 10
#define sc_wdd_date_y 11
#define sc_wdd_time 12
#define sc_wdd_time_h 13
#define sc_wdd_time_m 14
#define sc_wdd_time_s 15
#define sc_wdd_cause 16
#define sc_wdd_callnum 17
#define sc_wdd_chunk 18
#define sc_wdd_chunknum 19
#define sc_wdd_type 20
#define sc_chardisp 21
#define sc_isdn_call 22
#define sc_ether_direction 23

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE ascend_state_t *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 162 "ascend_scanner.l"


#line 2003 "ascend_scanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 487 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 486 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 164 "ascend_scanner.l"
{
  BEGIN(sc_ether_direction);
  yylval->d = ASCEND_PFX_ETHER;
  return ETHER_PREFIX;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 170 "ascend_scanner.l"
{
  BEGIN(sc_isdn_call);
  yylval->d = ASCEND_PFX_ISDN_X;
  return ISDN_PREFIX;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 176 "ascend_scanner.l"
{
  BEGIN(sc_isdn_call);
  yylval->d = ASCEND_PFX_ISDN_R;
  return ISDN_PREFIX;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 182 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  yylval->d = ASCEND_PFX_WDS_X;
  return WDS_PREFIX;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 188 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  yylval->d = ASCEND_PFX_WDS_R;
  return WDS_PREFIX;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 194 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  yylval->d = ASCEND_PFX_WDS_X;
  return WDS_PREFIX;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 200 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  yylval->d = ASCEND_PFX_WDS_R;
  return WDS_PREFIX;
}
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 206 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  return STRING;
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 211 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  return DECNUM;
}
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 216 "ascend_scanner.l"
{
  char *atcopy = g_strdup(yytext);
  char colon = input(yyscanner);
  char after = input(yyscanner);
  int retval = STRING;

  unput(after); unput(colon);

  if (after != '(' && after != ' ') {
    BEGIN(sc_wds_sess);
    if (yyextra->pseudo_header != NULL) {
      g_strlcpy(yyextra->pseudo_header->user, atcopy, ASCEND_MAX_STR_LEN);
    }
  } else {	/* We have a version 7 file */
    BEGIN(sc_gen_task);
    if (yyextra->pseudo_header != NULL) {
      g_strlcpy(yyextra->pseudo_header->user, NO_USER, ASCEND_MAX_STR_LEN);
    }
    /* Are valid values ever > 2^32? If so we need to adjust YYSTYPE and a lot of */
    /* upstream code accordingly. */
    yylval->d = (guint32) strtoul(yytext, NULL, 10);
    retval = DECNUM;
  }
  g_free (atcopy);
  return retval;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 243 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 249 "ascend_scanner.l"
{
  BEGIN(sc_gen_time_s);
  yylval->d = (guint32) strtoul(yytext, NULL, 16);
  return HEXNUM;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 255 "ascend_scanner.l"
{
  return STRING;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 259 "ascend_scanner.l"
{
  BEGIN(sc_gen_time_u);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 265 "ascend_scanner.l"
{
  char *atcopy = g_strdup(yytext);
  BEGIN(sc_gen_octets);
  /* only want the most significant 2 digits. convert to usecs */
  if (strlen(atcopy) > 2)
    atcopy[2] = '\0';
  yylval->d = (guint32) strtoul(atcopy, NULL, 10) * 10000;
  g_free(atcopy);
  return DECNUM;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 276 "ascend_scanner.l"
{
  BEGIN(sc_gen_counter);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 282 "ascend_scanner.l"
{
  BEGIN(sc_gen_byte);
  return COUNTER;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 287 "ascend_scanner.l"
{
  yylval->b = (guint8)(guint32) strtoul(yytext, NULL, 16);
  return HEXBYTE;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 292 "ascend_scanner.l"
{
  BEGIN(sc_chardisp);
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 296 "ascend_scanner.l"
{
  BEGIN(sc_gen_byte);
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 300 "ascend_scanner.l"
{
  BEGIN(sc_wdd_date_d);
  return WDD_DATE;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 305 "ascend_scanner.l"
{
  BEGIN(sc_wdd_date_m);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 311 "ascend_scanner.l"
{
  BEGIN(sc_wdd_date_y);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 317 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 323 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time_h);
  return KEYWORD;
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 328 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time_m);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 334 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time_s);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 340 "ascend_scanner.l"
{
  BEGIN(sc_wdd_cause);
  yylval->d = (guint32) strtoul(yytext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 346 "ascend_scanner.l"
{
  BEGIN(sc_wdd_callnum);
  return KEYWORD;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 351 "ascend_scanner.l"
{
  BEGIN(sc_wdd_chunk);
  if (yyextra->pseudo_header != NULL) {
    g_strlcpy(yyextra->pseudo_header->call_num, yytext, ASCEND_MAX_STR_LEN);
  }
  return STRING;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 359 "ascend_scanner.l"
{
  BEGIN(sc_wdd_chunknum);
  return WDD_CHUNK;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 364 "ascend_scanner.l"
{
  BEGIN(sc_wdd_type);
  yylval->d = (guint32) strtoul(yytext, NULL, 16);
  return HEXNUM;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 370 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  return KEYWORD;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 375 "ascend_scanner.l"
{
  return SLASH_SUFFIX;
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 379 "ascend_scanner.l"
{ return HEXNUM; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 381 "ascend_scanner.l"
{ return KEYWORD; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(sc_gen_task):
case YY_STATE_EOF(sc_gen_time_s):
case YY_STATE_EOF(sc_gen_time_u):
case YY_STATE_EOF(sc_gen_octets):
case YY_STATE_EOF(sc_gen_counter):
case YY_STATE_EOF(sc_gen_byte):
case YY_STATE_EOF(sc_wds_user):
case YY_STATE_EOF(sc_wds_sess):
case YY_STATE_EOF(sc_wdd_date_d):
case YY_STATE_EOF(sc_wdd_date_m):
case YY_STATE_EOF(sc_wdd_date_y):
case YY_STATE_EOF(sc_wdd_time):
case YY_STATE_EOF(sc_wdd_time_h):
case YY_STATE_EOF(sc_wdd_time_m):
case YY_STATE_EOF(sc_wdd_time_s):
case YY_STATE_EOF(sc_wdd_cause):
case YY_STATE_EOF(sc_wdd_callnum):
case YY_STATE_EOF(sc_wdd_chunk):
case YY_STATE_EOF(sc_wdd_chunknum):
case YY_STATE_EOF(sc_wdd_type):
case YY_STATE_EOF(sc_chardisp):
case YY_STATE_EOF(sc_isdn_call):
case YY_STATE_EOF(sc_ether_direction):
#line 383 "ascend_scanner.l"
{ yyterminate(); }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 385 "ascend_scanner.l"
;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 386 "ascend_scanner.l"
ECHO;
	YY_BREAK
#line 2424 "ascend_scanner.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 487 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 487 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 486);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

#define YYTABLES_NAME "yytables"

#line 386 "ascend_scanner.l"
